==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/IncompleteData.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "missingDataBeforeDateTime", 
    "wasThrottled"})
@JsonInclude(Include.NON_NULL)
public class IncompleteData implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("missingDataBeforeDateTime")
    protected OffsetDateTime missingDataBeforeDateTime;

    @JsonProperty("wasThrottled")
    protected Boolean wasThrottled;

    protected IncompleteData() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.incompleteData";
    }

    @Property(name="missingDataBeforeDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getMissingDataBeforeDateTime() {
        return Optional.ofNullable(missingDataBeforeDateTime);
    }

    public IncompleteData withMissingDataBeforeDateTime(OffsetDateTime missingDataBeforeDateTime) {
        IncompleteData _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.incompleteData");
        _x.missingDataBeforeDateTime = missingDataBeforeDateTime;
        return _x;
    }

    @Property(name="wasThrottled")
    @JsonIgnore
    public Optional<Boolean> getWasThrottled() {
        return Optional.ofNullable(wasThrottled);
    }

    public IncompleteData withWasThrottled(Boolean wasThrottled) {
        IncompleteData _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.incompleteData");
        _x.wasThrottled = wasThrottled;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime missingDataBeforeDateTime;
        private Boolean wasThrottled;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder missingDataBeforeDateTime(OffsetDateTime missingDataBeforeDateTime) {
            this.missingDataBeforeDateTime = missingDataBeforeDateTime;
            this.changedFields = changedFields.add("missingDataBeforeDateTime");
            return this;
        }

        public Builder wasThrottled(Boolean wasThrottled) {
            this.wasThrottled = wasThrottled;
            this.changedFields = changedFields.add("wasThrottled");
            return this;
        }

        public IncompleteData build() {
            IncompleteData _x = new IncompleteData();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.incompleteData";
            _x.missingDataBeforeDateTime = missingDataBeforeDateTime;
            _x.wasThrottled = wasThrottled;
            return _x;
        }
    }

    private IncompleteData _copy() {
        IncompleteData _x = new IncompleteData();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.missingDataBeforeDateTime = missingDataBeforeDateTime;
        _x.wasThrottled = wasThrottled;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("IncompleteData[");
        b.append("missingDataBeforeDateTime=");
        b.append(this.missingDataBeforeDateTime);
        b.append(", ");
        b.append("wasThrottled=");
        b.append(this.wasThrottled);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/IncompleteData.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "missingDataBeforeDateTime", 
    "wasThrottled"})
@JsonInclude(Include.NON_NULL)
public class IncompleteData implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("missingDataBeforeDateTime")
    protected OffsetDateTime missingDataBeforeDateTime;

    @JsonProperty("wasThrottled")
    protected Boolean wasThrottled;

    protected IncompleteData() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.incompleteData";
    }

    @Property(name="missingDataBeforeDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getMissingDataBeforeDateTime() {
        return Optional.ofNullable(missingDataBeforeDateTime);
    }

    public IncompleteData withMissingDataBeforeDateTime(OffsetDateTime missingDataBeforeDateTime) {
        IncompleteData _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.incompleteData");
        _x.missingDataBeforeDateTime = missingDataBeforeDateTime;
        return _x;
    }

    @Property(name="wasThrottled")
    @JsonIgnore
    public Optional<Boolean> getWasThrottled() {
        return Optional.ofNullable(wasThrottled);
    }

    public IncompleteData withWasThrottled(Boolean wasThrottled) {
        IncompleteData _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.incompleteData");
        _x.wasThrottled = wasThrottled;
        return _x;
    }

    public IncompleteData withUnmappedField(String name, Object value) {
        IncompleteData _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime missingDataBeforeDateTime;
        private Boolean wasThrottled;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder missingDataBeforeDateTime(OffsetDateTime missingDataBeforeDateTime) {
            this.missingDataBeforeDateTime = missingDataBeforeDateTime;
            this.changedFields = changedFields.add("missingDataBeforeDateTime");
            return this;
        }

        public Builder wasThrottled(Boolean wasThrottled) {
            this.wasThrottled = wasThrottled;
            this.changedFields = changedFields.add("wasThrottled");
            return this;
        }

        public IncompleteData build() {
            IncompleteData _x = new IncompleteData();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.incompleteData";
            _x.missingDataBeforeDateTime = missingDataBeforeDateTime;
            _x.wasThrottled = wasThrottled;
            return _x;
        }
    }

    private IncompleteData _copy() {
        IncompleteData _x = new IncompleteData();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.missingDataBeforeDateTime = missingDataBeforeDateTime;
        _x.wasThrottled = wasThrottled;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("IncompleteData[");
        b.append("missingDataBeforeDateTime=");
        b.append(this.missingDataBeforeDateTime);
        b.append(", ");
        b.append("wasThrottled=");
        b.append(this.wasThrottled);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
